spoon.NullLogger

Package spoon :: Class NullLogger |
[hide private]
[frames] | no frames]

# Class NullLogger

source code

    object --+
             |
            NullLogger

Dummy logging object. Doesn't do anything.

Instance Methods | [hide private]
`` | critical(self, msg, *args, **kwargs)
`` | debug(self, msg, *args, **kwargs)
`` | error(self, msg, *args, **kwargs)
`` | exception(self, msg, *args)
`` | info(self, msg, *args, **kwargs)
`` | log(self, lvl, msg, *args, **kwargs)
`` | warning(self, msg, *args, **kwargs)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### critical(self, msg, *args, **kwargs) | source code
None

### debug(self, msg, *args, **kwargs) | source code
None

### error(self, msg, *args, **kwargs) | source code
None

### exception(self, msg, *args) | source code
None

### info(self, msg, *args, **kwargs) | source code
None

### log(self, lvl, msg, *args, **kwargs) | source code
None

### warning(self, msg, *args, **kwargs) | source code
None